==> tasks-v1.8.8.zip: tasks/messages/cs/base.php <==
<?php

return [
    '1 Day before' => '1 den předem',
    '1 Month before' => '1 měsíc předem',
    '1 Week before' => '1 týden předem',
    '2 Days before' => '2 dny předem',
    '2 Weeks before' => '2 týdny předem',
    '3 Weeks before' => '3 týdny předem',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Přiřazení uživatelé</strong> mohou tento úkol zpracovat.',
    '<strong>Confirm</strong> task deletion' => '<strong>Potvrdit</strong> smazání úkolů',
    '<strong>Create</strong> task list' => '<strong>Vytvořit</strong> seznam úkolů',
    '<strong>Edit</strong> task' => '<strong>Upravit</strong> úkol',
    '<strong>Edit</strong> task list' => '<strong>Upravit</strong> seznam úkolů',
    '<strong>New</strong> Task' => '<strong>Nový</strong> úkol',
    '<strong>Task</strong> Overview' => '<strong>Přehled</strong> úkolů',
    '<strong>Tasks</strong>' => '<strong>Úkoly</strong>',
    '<strong>Tasks</strong> module configuration' => '<strong>Úkoly</strong> Konfigurace modulu',
    '<strong>Your</strong> tasks' => '<strong>Vaše</strong> úkoly',
    'Accept Task' => 'Přijmout úkol',
    'Add Deadline to space calendar' => 'Přidat termín do kalendáře prostoru',
    'Add checkpoint...' => 'Přidat kontrolní bod...',
    'Add entry to main navigation' => 'Přidání položky do hlavní navigace',
    'Add reminder' => 'Přidat připomínku',
    'Add responsible users' => 'Přidání odpovědných uživatelů',
    'Add schedule to the space calendar' => 'Přidání rozvrhu do kalendáře prostoru',
    'Add task' => 'Přidat úkol',
    'All Day' => 'Celý den',
    'Assign users' => 'Přiřaďte uživatele',
    'Close' => 'Zavřít',
    'Color' => 'Barva',
    'Created by me' => 'Vytvořil(a) jsem',
    'Date' => 'Datum',
    'Delete' => 'Smazat',
    'Description' => 'Popis',
    'Do you really want to delete this task?' => 'Opravdu chcete smazat tento úkol?',
    'Edit' => 'Upravit',
    'End' => 'Konec',
    'End Date' => 'Datum konce',
    'End Time' => 'Čas konce',
    'End time must be after start time!' => 'Datum konce události musí následovat po začátku!',
    'Filter' => 'Filtr',
    'General' => 'Obecné',
    'General Settings' => 'Hlavní nastavení',
    'Overview' => 'Přehled',
    'Pending' => 'Čekající',
    'Reminder' => 'Připomínka',
    'Sort Order' => 'Řazení',
    'Sort order' => 'Řazení',
    'Spaces' => 'prostor(y)',
    'Start' => 'Začít',
    'Start Date' => 'Datum začátku',
    'Start Time' => 'Čas začátku',
    'Status' => 'Stav',
    'Task' => 'Úkol',
    'Tasks' => 'Úkoly',
    'Time Zone' => 'Časové pásmo',
    'Title' => 'Název',
    'Today' => 'Dnes',
    'View Online' => 'Zobrazit online',
    'You have insufficient permissions to perform that operation!' => 'Pro tuto operaci nemáte dostatečná oprávnění!',
    '{userName} finished task {task}.' => '{userName} dokončil(a) úkol {task}.',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add to space calendar' => '',
    'Additional options' => '',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => '',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => '',
    'Allows the user to process unassigned tasks' => '',
    'Already requested' => '',
    'Any user with a "Process unassigned tasks" permission can work on this task' => '',
    'Anyone can work on this task!' => '',
    'Assign myself' => '',
    'Assigned' => '',
    'Assigned users' => '',
    'Assignment' => '',
    'Assignments:' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Begin Task' => '',
    'Checklist Items' => '',
    'Checklist:' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Continue Review' => '',
    'Create tasks' => '',
    'Deadline at' => '',
    'Deadline: ' => '',
    'Delete list' => '',
    'Do not remind' => '',
    'Don\'t add to calendar' => '',
    'Drag entry' => '',
    'Edit item (empty field will be removed)...' => '',
    'Edit list' => '',
    'End date' => '',
    'Extend deadline request' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'Filter tasks' => '',
    'Finish Task' => '',
    'Hide this list once all tasks are completed' => '',
    'I\'m assigned' => '',
    'I\'m responsible' => '',
    'If empty any user can complete the task.' => '',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => '',
    'In Progress' => '',
    'In Review' => '',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => '',
    'Invalid task list selection.' => '',
    'Let Task Review' => '',
    'Main Navigation' => '',
    'Manage tasks' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No Scheduling set for this Task' => '',
    'No pending tasks found' => '',
    'No results found for the given filter.' => '',
    'Open Task' => '',
    'Other Tasks' => '',
    'Overdue' => '',
    'Parent Task' => '',
    'Pending Review' => '',
    'Process unassigned tasks' => '',
    'Ready For Review' => '',
    'Receive Notifications for Task Reminder.' => '',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => '',
    'Reject Task' => '',
    'Remind Mode' => '',
    'Reminder sent' => '',
    'Reminders' => '',
    'Request extension' => '',
    'Request sent' => '',
    'Reset Task' => '',
    'Responsible' => '',
    'Responsible users' => '',
    'Review by responsible user required' => '',
    'Scheduling' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => '',
    'Start date' => '',
    'Starting at' => '',
    'Task List' => '',
    'Task Users have been notified' => '',
    'Task content ID' => '',
    'Task {task} in space {spaceName} ends at {dateTime}.' => '',
    'Task {task} in space {spaceName} starts at {dateTime}.' => '',
    'Tasks: Reminder' => '',
    'This task can only be processed by assigned and responsible users.' => '',
    'This task requires to be reviewed by a responsible' => '',
    'Title and Color' => '',
    'Title of your task list' => '',
    'Unsorted' => '',
    'You are assigned!' => '',
    'You are responsible!' => '',
    'Your Reminder for task {task}' => '',
    'ending Review' => '',
    'view all' => '',
    '{count,plural,=1{# day} other{# days}} remaining' => '',
    '{displayName} is assigned to this task' => '',
    '{displayName} is responsible for this task' => '',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '',
    '{userName} assigned you to task {task} in space {spaceName}.' => '',
    '{userName} completed Task {task} in space {spaceName}.' => '',
    '{userName} completed task {task}.' => '',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '',
    '{userName} has re-opened task {task} in space {spaceName}.' => '',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '',
    '{userName} reset task {task}.' => '',
    '{userName} reviewed task {task}.' => '',
    '{userName} started working on Task {task} in space {spaceName}.' => '',
    '{userName} works on task {task}.' => '',
];

==> tasks-v1.9.1.zip: tasks/messages/cs/base.php <==
<?php

return [
    '1 Day before' => '1 den předem',
    '1 Month before' => '1 měsíc předem',
    '1 Week before' => '1 týden předem',
    '2 Days before' => '2 dny předem',
    '2 Weeks before' => '2 týdny předem',
    '3 Weeks before' => '3 týdny předem',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Přiřazení uživatelé</strong> mohou tento úkol zpracovat.',
    '<strong>Confirm</strong> task deletion' => '<strong>Potvrdit</strong> smazání úkolů',
    '<strong>Create</strong> task list' => '<strong>Vytvořit</strong> seznam úkolů',
    '<strong>Edit</strong> task' => '<strong>Upravit</strong> úkol',
    '<strong>Edit</strong> task list' => '<strong>Upravit</strong> seznam úkolů',
    '<strong>New</strong> Task' => '<strong>Nový</strong> úkol',
    '<strong>Task</strong> Overview' => '<strong>Přehled</strong> úkolů',
    '<strong>Tasks</strong>' => '<strong>Úkoly</strong>',
    '<strong>Tasks</strong> module configuration' => '<strong>Úkoly</strong> Konfigurace modulu',
    '<strong>Your</strong> tasks' => '<strong>Vaše</strong> úkoly',
    'Accept Task' => 'Přijmout úkol',
    'Add Deadline to space calendar' => 'Přidat termín do kalendáře prostoru',
    'Add checkpoint...' => 'Přidat kontrolní bod...',
    'Add entry to main navigation' => 'Přidání položky do hlavní navigace',
    'Add reminder' => 'Přidat připomínku',
    'Add responsible users' => 'Přidání odpovědných uživatelů',
    'Add schedule to the space calendar' => 'Přidání rozvrhu do kalendáře prostoru',
    'Add task' => 'Přidat úkol',
    'All Day' => 'Celý den',
    'Assign users' => 'Přiřaďte uživatele',
    'Close' => 'Zavřít',
    'Color' => 'Barva',
    'Created by me' => 'Vytvořil(a) jsem',
    'Date' => 'Datum',
    'Delete' => 'Smazat',
    'Description' => 'Popis',
    'Do you really want to delete this task?' => 'Opravdu chcete smazat tento úkol?',
    'Edit' => 'Upravit',
    'End' => 'Konec',
    'End Date' => 'Datum konce',
    'End Time' => 'Čas konce',
    'End time must be after start time!' => 'Datum konce události musí následovat po začátku!',
    'Filter' => 'Filtr',
    'General' => 'Obecné',
    'General Settings' => 'Hlavní nastavení',
    'Overview' => 'Přehled',
    'Pending' => 'Čekající',
    'Reminder' => 'Připomínka',
    'Sort Order' => 'Řazení',
    'Sort order' => 'Řazení',
    'Spaces' => 'prostor(y)',
    'Start' => 'Začít',
    'Start Date' => 'Datum začátku',
    'Start Time' => 'Čas začátku',
    'Status' => 'Stav',
    'Task' => 'Úkol',
    'Tasks' => 'Úkoly',
    'Time Zone' => 'Časové pásmo',
    'Title' => 'Název',
    'Today' => 'Dnes',
    'View Online' => 'Zobrazit online',
    'You have insufficient permissions to perform that operation!' => 'Pro tuto operaci nemáte dostatečná oprávnění!',
    '{userName} finished task {task}.' => '{userName} dokončil(a) úkol {task}.',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add to space calendar' => '',
    'Additional options' => '',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => '',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => '',
    'Allows the user to process unassigned tasks' => '',
    'Already requested' => '',
    'Assign myself' => '',
    'Assigned users' => '',
    'Assignment' => '',
    'Assignments' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Begin Task' => '',
    'Checklist Items' => '',
    'Checklist:' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Continue Review' => '',
    'Create tasks' => '',
    'Deadline' => '',
    'Deadline: ' => '',
    'Delete list' => '',
    'Do not remind' => '',
    'Don\'t add to calendar' => '',
    'Edit item (empty field will be removed)...' => '',
    'Edit list' => '',
    'End date' => '',
    'Extend deadline request' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'Filter tasks' => '',
    'Finish Task' => '',
    'Hide this list once all tasks are completed' => '',
    'I\'m assigned' => '',
    'I\'m responsible' => '',
    'ID' => '',
    'If empty any user can complete the task.' => '',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => '',
    'In Progress' => '',
    'In Review' => '',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => '',
    'Invalid task list selection.' => '',
    'Let Task Review' => '',
    'Main Navigation' => '',
    'Manage tasks' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No Scheduling set for this Task' => '',
    'No pending tasks found' => '',
    'No results found for the given filter.' => '',
    'Open Task' => '',
    'Other Tasks' => '',
    'Overdue' => '',
    'Parent Task' => '',
    'Pending Review' => '',
    'Process unassigned tasks' => '',
    'Ready For Review' => '',
    'Receive Notifications for Task Reminder.' => '',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => '',
    'Reject Task' => '',
    'Remind Mode' => '',
    'Reminder sent' => '',
    'Reminders' => '',
    'Request Review' => '',
    'Request extension' => '',
    'Request sent' => '',
    'Reset Task' => '',
    'Responsible' => '',
    'Responsible users' => '',
    'Review by responsible user required' => '',
    'Scheduling' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => '',
    'Start date' => '',
    'Starting at' => '',
    'Task List' => '',
    'Task Users have been notified' => '',
    'Task content ID' => '',
    'Task {task} in space {spaceName} ends at {dateTime}.' => '',
    'Task {task} in space {spaceName} starts at {dateTime}.' => '',
    'Tasks: Reminder' => '',
    'This task requires to be reviewed by a responsible' => '',
    'Title and Color' => '',
    'Title of your task list' => '',
    'Unsorted' => '',
    'Your Reminder for task {task}' => '',
    'view all' => '',
    '{count,plural,=1{# day} other{# days}} remaining' => '',
    '{displayName} is assigned to this task' => '',
    '{displayName} is responsible for this task' => '',
    '{displayName} is task creator' => '',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '',
    '{userName} assigned you to task {task} in space {spaceName}.' => '',
    '{userName} completed Task {task} in space {spaceName}.' => '',
    '{userName} completed task {task}.' => '',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '',
    '{userName} has re-opened task {task} in space {spaceName}.' => '',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '',
    '{userName} reset task {task}.' => '',
    '{userName} reviewed task {task}.' => '',
    '{userName} started working on Task {task} in space {spaceName}.' => '',
    '{userName} works on task {task}.' => '',
];
